@@ -5,13 +5,11 @@ from dagster.core.events.log import DagsterEventRecord
 
 def validate_pipeline_execution(pipeline_exc_result):
     expected_airflow_demo_events = {
-        ('ENGINE_EVENT', 'multiply_the_word.compute'),
         ('STEP_START', 'multiply_the_word.compute'),
         ('STEP_INPUT', 'multiply_the_word.compute'),
         ('STEP_OUTPUT', 'multiply_the_word.compute'),
         ('OBJECT_STORE_OPERATION', 'multiply_the_word.compute'),
         ('STEP_SUCCESS', 'multiply_the_word.compute'),
-        ('ENGINE_EVENT', 'count_letters.compute'),
         ('STEP_START', 'count_letters.compute'),
         ('OBJECT_STORE_OPERATION', 'count_letters.compute'),
         ('STEP_INPUT', 'count_letters.compute'),
@@ -27,7 +25,9 @@ def validate_pipeline_execution(pipeline_exc_result):
             else:
                 seen_events.add((event.event_type_value, event.step_key))
 
-    assert seen_events == expected_airflow_demo_events
+    # there may be additional engine events for resources when present
+    # just ensure we saw of what we expected
+    assert expected_airflow_demo_events.difference(seen_events) == set()
 
 
 def validate_skip_pipeline_execution(result):
